@@ -11,9 +11,12 @@ import java.util.*;
 
 class Fun {
   String name;
-  Vector args = new Vector();
+  Vector<String> args = new Vector<>();
   Exp body;
   Builtin builtin = null;
-  Fun(String s) { name = s; }
+
+  Fun(String s) {
+    name = s;
+  }
 }
 
