@@ -9,14 +9,15 @@
 package org.redmars.wadc;
 import java.util.*;
 
-public class Sector {
+class Sector {
   int idx;
   int ceil, floor;
   String ctex, ftex;
   int light;
   int type, tag;
   int boundlen;
-  Sector(String c, String f, int h, int l, int ll, Vector addto, int type, int tag) {
+
+  Sector(String c, String f, int h, int l, int ll, List<Sector> addto, int type, int tag) {
     ctex = c; ftex = f;
     ceil = h; floor = l;
     this.type = type;
@@ -24,6 +25,6 @@ public class Sector {
     light = ll;
     boundlen = 0;
     idx = addto.size();
-    addto.addElement(this);
+    addto.add(this);
   }
 }
