@@ -17,10 +17,11 @@ class Texture {
     String name;
     int width, height;
     ArrayList<Patch> patches;
+
     public Texture(String n, int w, int h) {
         name = n;
         width = w;
         height = h;
-        patches = new ArrayList<Patch>();
+        patches = new ArrayList<>();
     }
 }
